<?php
/**
 * Cache service
 */

namespace Clickio\CacheControl;

use Clickio\Logger as log;


/**
 * Abstract cache service
 *
 * @package CacheControl
 */
abstract class ServiceBase implements Interfaces\ICacheService
{
    /**
     * Logger
     *
     * @var ILogger
     */
    protected $log = null;

    /**
     * Interface method
     * For more information see method defenition
     *
     * @param array $urllist list of urls
     *
     * @return void
     */
    abstract public function clear(array $urllist);

    /**
     * Constructor
     *
     * @param ILogger $logger logger instance
     */
    public function __construct(log\Interfaces\ILogger $logger)
    {
        $this->log = $logger;
    }

    /**
     * Logger method wrapper
     * Write debug message
     *
     * @param string $msg log message
     * @param array $debugInfo extra debug information
     *
     * @return void
     */
    protected function debug(string $msg, array $debugInfo)
    {
        $msg = sprintf("%s service: %s\n", static::class, $msg);
        $this->log->debug($msg, $debugInfo);
    }

    /**
     * Logger method wrapper
     * Write info message
     *
     * @param string $msg log message
     *
     * @return void
     */
    protected function info(string $msg)
    {
        $msg = sprintf("%s service: %s\n", static::class, $msg);
        $this->log->info($msg);
    }

    /**
     * Getter
     * Get human-readable label
     *
     * @return void
     */
    public function getLabel()
    {
        return $this->label;
    }

    /**
     * Getter
     * Get description
     *
     * @return string
     */
    public function getDescription()
    {
        return $this->desc;
    }

    /**
     * Recursive remove dir
     *
     * @param string $src path to be removed
     *
     * @return void
     */
    protected function rrmdir($src)
    {
        $dir = opendir($src);
        if (!$dir) {
            return ;
        }
        while (false !== ($file = readdir($dir))) {
            if (in_array($file, ['..', '.'])) {
                continue;
            }

            $full = implode(DIRECTORY_SEPARATOR, [$src, $file]);
            if (is_dir($full)) {
                $this->rrmdir($full);
            } else {
                unlink($full);
            }
        }
        closedir($dir);
        rmdir($src);
    }
}