<?php
/**
 * Extra content factory
 */

namespace Clickio\ExtraContent;

use Clickio\ExtraContent\Interfaces\IExtraContentService;
use Clickio\Logger\Logger;

/**
 * Service factory
 *
 * @package ExtraContent
 */
class ExtraContentServiceFactory
{
    protected static $services = [];

    /**
     * Factory method
     *
     * @param string $name service FQCN
     *
     * @return IExtraContentService
     */
    public static function create(string $name): IExtraContentService
    {
        $logger = Logger::getLogger($_SERVER['HTTP_HOST']);
        return new $name($logger);
    }

    /**
     * Create all services
     *
     * @return array
     */
    public static function createAll(): array
    {
        $serv_list = [];
        foreach (static::$services as $serv) {
            $serv_list[] = static::create($serv);
        }
        return $serv_list;
    }

    /**
     * Discover all services
     *
     * @return void
     */
    public static function discover()
    {
        $service_location = sprintf("%s/Services", dirname(__FILE__));
        foreach (scandir($service_location) as $path) {
            if (in_array($path, ['.', '..'])) {
                continue ;
            }

            $service_class = sprintf("%s\Services\%s", __NAMESPACE__, basename($path, '.php'));
            $ifaces = class_implements($service_class);
            if (in_array(IExtraContentService::class, $ifaces)) {
                static::$services[] = $service_class;
            }
        }
    }
}