<?php
/**
 * Listing builder factory
 */

namespace Clickio\Listings;

use Clickio\Listings\Interfaces\IListingBuilder;

/**
 * Builder Factory
 *
 * @package Listings
 */
class BuilderFactory
{
    /**
     * Only one discover
     *
     * @var bool
     */
    private static $_discovered = false;

    /**
     * Builders map
     *
     * @var array
     */
    protected static $builders_map = [];

    /**
     * Auto discover all builder
     *
     * @return void
     */
    public static function discover()
    {
        if (static::$_discovered) {
            return ;
        }

        $dir_path = sprintf("%s/Builders", dirname(__FILE__));
        foreach (scandir($dir_path) as $target) {
            if (in_array($target, ['.', '..'])) {
                continue ;
            }

            $cls = sprintf("%s\%s\%s", __NAMESPACE__, "Builders", basename($target, '.php'));
            $implements = class_implements($cls, true);
            if (!empty($implements) && in_array(IListingBuilder::class, $implements)) {
                $alias = $cls::getAlias();
                static::$builders_map[$alias] = $cls;
            }
        }

        static::$_discovered = true;
    }

    /**
     * Get all available builders
     *
     * @return array
     */
    public static function getBuilders(): array
    {
        if (empty(static::$builders_map)) {
            static::discover();
        }
        return static::$builders_map;
    }

    /**
     * Factory method
     * Create new Listing builder
     *
     * @param string $builder builder
     * @param array $args builder args
     *
     * @return IListingBuilder
     */
    public static function create(string $builder, array $args): IListingBuilder
    {

        if (static::builderExists($builder)) {
            $builders = static::getBuilders();
            $cls = $builders[$builder];
            return new $cls(...$args);
        }
        throw new \Exception("Builder $builder doesn't exists");
    }

    /**
     * Check were builder exists
     *
     * @param string $builder builder alias
     *
     * @return bool
     */
    public static function builderExists(string $builder): bool
    {
        $builders = static::getBuilders();
        return array_key_exists($builder, $builders);
    }
}