<?php
/**
 * Attachment builder
 */

namespace Clickio\Listings\Builders;

use Clickio\Integration\Services\WordPressPopularPosts;
use Clickio\Listings\FilterItemContainer;
use Clickio\Listings\FilterListingContainer;
use Clickio\Listings\FilterParamsContainer;
use Clickio\Listings\Interfaces\IListingBuilder;

/**
 * Build listing by popularity
 *
 * @package Listings\Builders
 */
final class MostPopularBuilder extends PostBuilder implements IListingBuilder
{

    /**
     * Builder alias
     *
     * @var string
     */
    const ALIAS = 'mostpopular';

    /**
     * Builder main function
     *
     * @param FilterParamsContainer $params query result
     *
     * @return FilterListingContainer
     */
    public function build(FilterParamsContainer $params): FilterListingContainer
    {
        $listings = new FilterListingContainer();

        $posts = $this->getWppPostsIds($params);
        $params->post__in = $posts;
        $params->endpoint = '';

        return parent::build($params);
    }

    /**
     * Get posts from WordPress Popular Posts
     *
     * @param FilterParamsContainer $params filter parameters
     *
     * @return array
     */
    protected function getWppPostsIds(FilterParamsContainer $params): array
    {
        $wpp_params = [
            'limit' => $params->posts_per_page,
            'range' => 'last24hours',
            'freshness' => 1,
            'order_by' => 'views',
        ];
        $posts = WordPressPopularPosts::getPopularPosts($wpp_params);
        return $posts;
    }
}