<?php
/**
 * Cache manager
 */

namespace Clickio\Prism\Cache;

use Clickio\ClickioPlugin;
use Clickio\Logger\Interfaces\ILogger;
use Clickio\Utils\CacheUtils;
use Clickio\Utils\SafeAccess;

/**
 * Cache manager
 *
 * @package Prism\Cache
 */
class CacheManager
{

    /**
     * Flag to stop caching
     *
     * @var bool
     */
    protected static $force_stop_caching = false;

    /**
     * Logger instance
     *
     * @var ILogger
     */
    protected $log = null;

    /**
     * Cache container
     *
     * @var string
     */
    private static $_cached_out = '';

    /**
     * Singletone container
     *
     * @var self
     */
    private static $_inst = null;

    /**
     * Constructor
     *
     * @param ILogger $log logger instance
     */
    public function __construct(ILogger $log)
    {
        $this->log = $log;
    }

    /**
     * Cache callback
     *
     * @param string $buffer output buffer
     *
     * @return void
     */
    public static function cacheOutputBuffer($buffer)
    {
        if (static::$force_stop_caching) {
            return $buffer;
        }

        static::$_cached_out .= $buffer;
        return $buffer;
    }

    /**
     * Flush buffer into cache repo
     *
     * @return void
     */
    public static function saveBuffer()
    {
        if (empty(static::$_cached_out)) {
            return ;
        }

        $repo = CacheRepo::getInstance();
        $url = SafeAccess::fromArray($_SERVER, 'REQUEST_URI', 'string', '');
        $repo->set($url, static::$_cached_out);
    }

    /**
     * Start caching
     *
     * @return void
     */
    public function startCache()
    {
        static::$force_stop_caching = false;
        ob_start([static::class, 'cacheOutputBuffer']);
        CacheUtils::setCacheStatusHeader(false);
    }

    /**
     * Stop caching
     *
     * @return void
     */
    public function stopCache()
    {
        static::$force_stop_caching = true;
        static::$_cached_out = '';
    }

    /**
     * Factory method
     *
     * @param bool $force force to recreate manager
     *
     * @return self
     */
    public static function make(bool $force = false): self
    {
        if (!static::$_inst || $force) {
            $logger = (ClickioPlugin::getInstance())->getLogger();
            $mngr = new static($logger);
            static::$_inst = $mngr;
        }

        return static::$_inst;
    }
}