<?php
/**
 * Rest api action
 */

namespace Clickio\RestApi\Actions;

use Clickio\RestApi as rest;

/**
 * Read logfile line by line
 *
 * Example:
 *      GET http://domain.name/wp-json/clickio/log?date=YYYY-MM-DD&offset=50
 *
 * @package RestApi\Actions
 */
class LogReader extends rest\BaseRestAction implements rest\Interfaces\IRestApi
{
    /**
     * Log date
     *
     * @var string
     */
    protected $date = "";

    /**
     * Amount of lines
     *
     * @var int
     */
    protected $offset = 50;

    /**
     * Handle http get method
     *
     * @return mixed
     */
    public function get()
    {
        $date = $this->request->get_param('date');
        if (!empty($date)) {
            $dt = date("Y_m_d", strtotime($date));
            $this->date = $dt;
        }

        $offset = $this->request->get_param('offset');
        if (!empty($offset) && $offset >= 1) {
            if ($offset > 5000) {
                $offset = 5000;
            }
            $this->offset = $offset;
        }

        $rows = $this->getLogData();
        return $rows;
    }

    /**
     * Read log $offset lines from the end of file
     *
     * @return array
     */
    protected function getLogData(): array
    {
        $log_file = $this->log->getAbsPath($this->date);
        $file = file($log_file);
        $file = array_reverse($file);
        $lines = [];
        foreach (range(0, $this->offset) as $line) {
            if (isset($file[$line])) {
                $lines[] = $file[$line];
            } else {
                break;
            }
        }
        return array_reverse($lines);
    }
}