<?php
/**
 * Rest api action
 */

namespace Clickio\RestApi\Actions;

use Clickio\CacheControl\CacheManager;
use Clickio\RestApi as rest;
use Clickio\Utils\SafeAccess;

/**
 * Confirm authority when requesting Clickio service
 *
 * Example:
 *      POST http://domain.name/wp-json/clickio/purge_cache/
 *          {
 *              all_pages: 0
 *              pages: [...]
 *          }
 *
 * @package RestApi\Actions
 */
class PurgeCache extends rest\BaseRestAction implements rest\Interfaces\IRestApi
{
    /**
     * Handle http post method
     *
     * @return mixed
     */
    public function post()
    {

        $params = $this->getPayload();
        if (empty($params)) {
            return new \WP_REST_Response(null, 400);
        }
        $all = SafeAccess::fromArray($params, 'all', 'integer', 0);
        $pages = SafeAccess::fromArray($params, 'pages', 'array', []);
        CacheManager::purge($all, $pages);
        return new \WP_REST_Response(null, 202);
    }
}