<?php
/**
 * Rest API factory
 */

namespace Clickio\RestApi;

use Clickio\RestApi as rest;
use Clickio\Logger as log;

/**
 * Rest api factory
 *
 * @package RestApi
 */
class RestApiFactory
{

    /**
     * Create action
     *
     * @param string $name action name in PSR-4
     * @param array $params extra params
     *
     * @return rest\Interfaces\IRestApi
     */
    public static function create(string $name, array $params = []): rest\Interfaces\IRestApi
    {
        $logger = log\Logger::getLogger($_SERVER['HTTP_HOST']);
        return new $name($logger, ...$params);
    }

    /**
     * Create rest api manager
     *
     * @param string $type manager type
     * @param array $params manager extra params
     *
     * @return rest\Interfaces\IRestApiManager
     */
    public static function createManager(string $type, array $params = []): rest\Interfaces\IRestApiManager
    {
        $logger = log\Logger::getLogger($_SERVER['HTTP_HOST']);
        switch($type){
            case 'default':
                return new rest\RestApiManager($logger, ...$params);
            default:
                throw new \Exception("No manager with type $type was found");
        }
    }
}