<?php

/**
 * Get embed content
 */

namespace Clickio\Utils;

/**
 * Embed content
 *
 * @package Utils
 */
class OEmbed
{
    /**
     * Embed meta fields
     *
     * @var array
     */
    protected $embed_fields = [
        "video_url",
        "_video_url"
    ];

    /**
     * Singletone instance
     *
     * @var ?OEmbed
     */
    private static $_inst = null;

    /**
     * Get vidoe html
     *
     * @param int $post_id post ID
     *
     * @return string
     */
    public function getEmbedHtml(int $post_id = 0): string
    {
        $oembed_url = $this->getOembedUrl($post_id);
        $embed_html = wp_oembed_get($oembed_url);
        return $embed_html;
    }

    /**
     * Get vidoe url
     *
     * @param int $post_id post ID
     *
     * @return string
     */
    public function getOembedUrl(int $post_id = 0): string
    {
        foreach ($this->embed_fields as $meta_key) {
            $meta = get_post_meta($post_id, $meta_key, true);
            if (!empty($meta)) {
                return $meta;
            }
        }
        return '';
    }

    /**
     * Factory method
     * Create singletone
     *
     * @return self
     */
    public static function getInstance(): self
    {
        if (empty(static::$_inst)) {
            static::$_inst = new static();
        }
        return static::$_inst;
    }

    /**
     * Static alias for getEmbedHtml
     *
     * @param int $post_id post ID
     *
     * @return string
     */
    public static function getEmbed(int $post_id = 0): string
    {
        $inst = static::getInstance();
        return $inst->getEmbedHtml($post_id);
    }
}