<?php

/**
 * Permalink helper
 */

namespace Clickio\Utils;

use Clickio\Meta\PostMeta;
use Clickio\Meta\TermMeta;

/**
 * Wrapper to get permalink of any object
 *
 * @package Utils
 */
final class Permalink
{

    /**
     * Get url of current location
     *
     * @return string
     */
    public static function getCurrentLocationUrl(): string
    {
        global $wp;
        $url = '';
        switch(LocationType::getType()){
            case "home":
                $url = self::getHomeUrl();
                break;
            case "post":
                $url = self::getPostUrl();
                break;
            case 'taxonomy':
                $url = self::getTaxonomyUrl();
                break;
            case 'archive':
                $url = self::getArchiveUrl();
                break;
            default:
                $url = home_url($wp->request);
        }
        return $url;
    }

    /**
     * Get home page url
     *
     * @return string
     */
    public static function getHomeUrl(): string
    {
        return home_url();
    }

    /**
     * Post url
     *
     * @param int $id post id, leave empty when in the loop
     *
     * @return string
     */
    public static function getPostUrl(int $id = 0):string
    {
        if (empty($id)) {
            $id = get_the_ID();
        }
        $post_meta = PostMeta::createFromId($id);
        return $post_meta->getPermalink();
    }

    /**
     * Get url to taxonomy
     *
     * @param int $term_id taxonomy term id, leave empty when in the loop
     *
     * @return string
     */
    public static function getTaxonomyUrl(int $term_id = 0): string
    {
        if (empty($term_id)) {
            $term_id = get_queried_object_id();
        }
        $term = TermMeta::createFromId($term_id);
        return $term->getPermalink();
    }

    /**
     * Get url to post archive
     *
     * @param string $type archive type, leave empty when in the loop
     *
     * @return string
     */
    public static function getArchiveUrl(string $type = ''): string
    {
        if (empty($id)) {
            $id = get_the_ID();
            $post = get_post($id);
            $type = $post->post_type;
        }

        return get_post_type_archive_link($type);
    }
}